@@ -371,8 +371,7 @@ bool implCreateIteratedNodes(
         {
             // will not animate the whole paragraph, when
             // only the paragraph is animated at all.
-            OSL_ENSURE( false,
-                        "implCreateIteratedNodes(): Ignoring paragraph iteration for paragraph master" );
+            OSL_FAIL( "implCreateIteratedNodes(): Ignoring paragraph iteration for paragraph master" );
         }
         else
         {
@@ -475,7 +474,7 @@ BaseNodeSharedPtr implCreateAnimationNode(
     switch( xNode->getType() )
     {
     case animations::AnimationNodeType::CUSTOM:
-        OSL_ENSURE( false, "implCreateAnimationNode(): "
+        OSL_FAIL( "implCreateAnimationNode(): "
                     "CUSTOM not yet implemented" );
         return pCreatedNode;
         
@@ -538,7 +537,7 @@ BaseNodeSharedPtr implCreateAnimationNode(
         break;
         
     default:
-        OSL_ENSURE( false, "implCreateAnimationNode(): "
+        OSL_FAIL( "implCreateAnimationNode(): "
                     "invalid AnimationNodeType" );
         return pCreatedNode;
     }
@@ -579,7 +578,7 @@ BaseNodeSharedPtr implCreateAnimationNode(
             NodeCreator aCreator( pCreatedContainer, rContext );
             if( !::anim::for_each_childNode( xNode, aCreator ) )
             {
-                OSL_ENSURE( false, "implCreateAnimationNode(): "
+                OSL_FAIL( "implCreateAnimationNode(): "
                             "child node creation failed" );
                 return BaseNodeSharedPtr();
             }
