@@ -228,57 +228,6 @@ namespace slideshow
             return maHSLTriple.mnLuminance;
         }
 
-        double HSLColor::getRed() const
-        {
-            if( ::basegfx::fTools::equalZero( getSaturation() ) )
-                return getLuminance();
-
-            return hsl2rgbHelper( 2.0*getLuminance() - mnMagicValue, 
-                                  mnMagicValue, 
-                                  getHue() + 120.0 );
-        }
-
-        double HSLColor::getGreen() const
-        {
-            if( ::basegfx::fTools::equalZero( getSaturation() ) )
-                return getLuminance();
-
-            return hsl2rgbHelper( 2.0*getLuminance() - mnMagicValue, 
-                                  mnMagicValue, 
-                                  getHue() );
-        }
-
-        double HSLColor::getBlue() const
-        {
-            if( ::basegfx::fTools::equalZero( getSaturation() ) )
-                return getLuminance();
-
-            return hsl2rgbHelper( 2.0*getLuminance() - mnMagicValue, 
-                                  mnMagicValue, 
-                                  getHue() - 120.0 );
-        }
-
-        RGBColor HSLColor::getRGBColor() const
-        {
-            RGBColor::RGBTriple aColor( hsl2rgb( getHue(),
-                                                 getSaturation(),
-                                                 getLuminance() ) );
-            return RGBColor( aColor.mnRed, aColor.mnGreen, aColor.mnBlue );
-        }
-         
-        RGBColor::RGBColor(const RGBColor& rLHS)
-            : maRGBTriple( rLHS.maRGBTriple )
-        {
-        }
-
-        RGBColor& RGBColor::operator=( const RGBColor& rLHS ){
-
-            maRGBTriple.mnRed = rLHS.getRed();
-            maRGBTriple.mnGreen = rLHS.getGreen();
-            maRGBTriple.mnBlue = rLHS.getBlue();
-            return *this;
-        }        
-
         HSLColor operator+( const HSLColor& rLHS, const HSLColor& rRHS )
         {
             return HSLColor( rLHS.getHue() + rRHS.getHue(),
@@ -385,27 +334,6 @@ namespace slideshow
         {
         }
                          
-        double RGBColor::getHue() const
-        {
-            return rgb2hsl( getRed(),
-                            getGreen(),
-                            getBlue() ).mnHue;
-        }
-
-        double RGBColor::getSaturation() const
-        {
-            return rgb2hsl( getRed(),
-                            getGreen(),
-                            getBlue() ).mnSaturation;
-        }
-
-        double RGBColor::getLuminance() const
-        {
-            return rgb2hsl( getRed(),
-                            getGreen(),
-                            getBlue() ).mnLuminance;
-        }
-
         double RGBColor::getRed() const
         {
             return maRGBTriple.mnRed;
@@ -421,14 +349,6 @@ namespace slideshow
             return maRGBTriple.mnBlue;
         }
 
-        HSLColor RGBColor::getHSLColor() const
-        {
-            HSLColor::HSLTriple aColor( rgb2hsl( getRed(),
-                                                 getGreen(),
-                                                 getBlue() ) );
-            return HSLColor( aColor.mnHue, aColor.mnSaturation, aColor.mnLuminance );
-        }        
-
         ::cppcanvas::Color::IntSRGBA RGBColor::getIntegerColor() const
         {
             return ::cppcanvas::makeColor( colorToInt( getRed() ),
